==> user_referral-2.0.1.tar.gz: user_referral/modules/user_referral_domain/src/Plugin/ExtraField/Display/ReferralLinkForDomain.php <==
<?php

namespace Drupal\user_referral_domain\Plugin\ExtraField\Display;

use Drupal\Core\Entity\ContentEntityInterface;
use Drupal\extra_field_plus\Plugin\ExtraFieldPlusDisplayFormattedBase;
use Drupal\user_referral\Entity\UserReferralType;
use Drupal\user_referral\Plugin\ExtraField\Display\ReferralLink;
use Drupal\domain\Entity\Domain;

/**
 * Example Node Label Extra field with formatted output.
 *
 * @ExtraFieldDisplay(
 *   id = "user_referral_link_domain",
 *   deriver = "\Drupal\user_referral_domain\Plugin\Derivative\ReferralLinkForDomainDeriver",
 *   bundles = {
 *     "user.*",
 *   },
 *   visible = false
 * )
 */
class ReferralLinkForDomain extends ReferralLink {

  /**
   * {@inheritdoc}
   */
  public function viewElements(ContentEntityInterface $entity) {
    $settings = $this->getSettings();

    $referral_type = $this->getReferralType();
    $domain = $this->getDomain();

    $element = [];

    if ($entity->id()) {
      $element = [
        '#type' => 'referral_link',
          '#title' => t('@type referral link for %domain domain', ['@type' => $referral_type->label(), '%domain' => $domain->get('name')]),
          '#referral_link' => $referral_type->getReferralLink($entity, ['base_path' => rtrim($domain->getPath(), '/')]),
          '#referral_type' => $referral_type,
          '#account' => $entity,
          '#attached' => [
            'library' => ['user_referral/drupal'],
          ],
      ];
    }

    return $element;
  }

  public function getReferralType() {
    $parts = explode(':', $this->pluginId);
    array_pop($parts); // Remove domain ID
    return UserReferralType::load(array_pop($parts));
  }

  public function getDomain() {
    $parts = explode(':', $this->pluginId);
    $domains = \Drupal::entityTypeManager()
        ->getStorage('domain')
        ->loadByProperties(['domain_id' => array_pop($parts)]);
    if (count($domains)) {
      return reset($domains);
    }
    return NULL;
  }

}

==> user_referral-3.1.1.tar.gz: user_referral/modules/user_referral_domain/src/Plugin/ExtraField/Display/ReferralLinkForDomain.php <==
<?php

namespace Drupal\user_referral_domain\Plugin\ExtraField\Display;

use Drupal\Core\Entity\ContentEntityInterface;
use Drupal\extra_field_plus\Plugin\ExtraFieldPlusDisplayFormattedBase;
use Drupal\user_referral\Entity\UserReferralType;
use Drupal\user_referral\Plugin\ExtraField\Display\ReferralLink;
use Drupal\domain\Entity\Domain;
use Drupal\Component\Plugin\PluginBase;

/**
 * Example Node Label Extra field with formatted output.
 *
 * @ExtraFieldDisplay(
 *   id = "user_referral_link_domain",
 *   deriver = "\Drupal\user_referral_domain\Plugin\Derivative\ReferralLinkForDomainDeriver",
 *   bundles = {
 *     "user.*",
 *   },
 *   visible = false
 * )
 */
class ReferralLinkForDomain extends ReferralLink {

  /**
   * {@inheritdoc}
   */
  public function viewElements(ContentEntityInterface $entity) {
    $settings = $this->getEntityExtraFieldSettings();

    $referral_type = $this->getReferralType();
    /** @var \Drupal\domain\Entity\Domain */
    $domain = $this->getDomain();

    $element = [];

    if ($entity->id()) {
      $element = [
        '#type' => 'referral_link',
          '#title' => t('@type referral link for %domain domain', ['@type' => $referral_type->label(), '%domain' => $domain->get('name')]),
          '#referral_link' => $referral_type->getReferralLink($entity, ['base_path' => rtrim($domain->getPath(), '/')]),
          '#referral_type' => $referral_type,
          '#account' => $entity,
          '#attached' => [
            'library' => ['user_referral/drupal'],
          ],
      ];
    }

    return $element;
  }

  public function getReferralType() {
    $parts = explode(PluginBase::DERIVATIVE_SEPARATOR, $this->getPluginDefinition()['id']);
    return UserReferralType::load($parts[1]);
  }

  public function getDomain() {
    $parts = explode(PluginBase::DERIVATIVE_SEPARATOR, $this->getPluginDefinition()['id']);
    $domains = \Drupal::entityTypeManager()
        ->getStorage('domain')
        ->loadByProperties(['domain_id' => $parts[2]]);
    if (count($domains)) {
      return reset($domains);
    }
    return NULL;
  }

}
